# PostCSS Bootstrap icons

This [PostCSS](https://github.com/postcss/postcss) plugin  
creates `svg` icons from [Bootstrap's icon set](https://icons.getbootstrap.com/). 
Use it with Vite and Tailwind frameworks.

## How does it work

Before:

```css
.some-class{
    @icon bi github
}
```

After:

```css
.some-class{
    background-image(img/icons/bi-github.svg);
}
```

## Quick start

For setting the plugin up:

* [init your Vite project with PostCSS and Tailwind](https://tailwindcss.com/docs/guides/vite);
* install the plugin running `npm i -D postcss-bootstrap-icons`;
* setup your `postcss.config.cjs`

    ```javascript
    module.exports = {
        plugins: [
            require('postcss-bootstrap-icons'),
            require('autoprefixer'),
            require('tailwindcss')
        ]
    }
    ```
* execute in your terminal `cp node_modules/postcss-bootstrap-icons/bootstrap-icons.css src`;
* append line `import "./bootstrap-icons.css"` to import section of your `src/main.{js|ts}`;
* uncomment desired icons in `src/bootstrap-icons.css`;
* make directory `public/img/icons` *manually*;
* execute in your terminal `npm run dev`;
* add the icon to your html anywhere using:

    ```html
    <i class="bi github xs"></i><!-- extra small -->
    <i class="bi github sm"></i><!-- small -->
    <i class="bi github base"></i><!-- base -->
    <i class="bi github lg"></i><!-- large -->
    <i class="bi github xl"></i><!-- extra large -->
    ```

